@@ -361,3 +361,11 @@ I wept like a child. "Dear mountains! my own beautiful lake! how do you welcome
                   ' "It\'s polite, see? Yeh walk toward him, and yeh bow, an\' yeh wait.',
                   " If he bows back, yeh're allowed ter toych him. If he desn' bow, then get away from him sharpish,' cause those talons hurt."]
         self.assertEqual(expect, acutal)
+
+    def test_bug_2021_5_26(self):
+        paragraph = "In the new economy, computer science isn't an optional skill – it's a basic skill, right along with the three \"Dr.\" Steven Nine out of ten parents want it taught at their children's schools"
+        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=30))
+        m_input = EnSequence(paragraph)
+        __long_machine_en.run(m_input)
+        acutal = m_input.sentence_list()
+        print(acutal)
